[−][src]Struct conquer_once::doc::Lazy
A type for lazy initialization of e.g. global static variables, which
provides the same functionality as the lazy_static! macro.
Implementations
impl<T, B, F> Lazy<T, B, F>[src]
pub const fn new(init: F) -> Self[src]
Creates a new uninitialized Lazy with the given init closure.
Examples
The init argument can be a simple function pointer or any FnOnce
closure.
use conquer_once::Lazy; static LAZY_1: Lazy<Vec<i32>> = Lazy::new(|| vec![1, 2, 3, 4, 5]); static LAZY_2: Lazy<Vec<i32>> = Lazy::new(Vec::<i32>::new);
pub fn is_initialized(lazy: &Self) -> bool[src]
Returns true if the Lazy has been successfully initialized.
pub fn is_poisoned(lazy: &Self) -> bool[src]
Returns true if the Lazy has been poisoned.
impl<T, B, F> Lazy<T, B, F> where
B: Block,
F: FnOnce() -> T, [src]
B: Block,
F: FnOnce() -> T,
pub fn get_or_init(lazy: &Self) -> &T[src]